Package: qemulator
Severity: minor

The package has many typos of words 'allready' and 'snpashot'. Attached patch
fixes bug.


-- System Information:
Debian Release: squeeze/sid
  APT prefers maverick-updates
  APT policy: (500, 'maverick-updates'), (500, 'maverick-security'), (500, 
'maverick')
Architecture: i386 (i686)

Kernel: Linux 2.6.35-19-generic (SMP w/2 CPU cores)
Locale: LANG=en_US.utf8, LC_CTYPE=en_US.utf8 (charmap=UTF-8)
Shell: /bin/sh linked to /bin/dash
--- qemulator-0.5.orig/TRANSLATION
+++ qemulator-0.5/TRANSLATION
@@ -1,4 +1,4 @@
-Qemulator now have multilanguage support. If you are interested in making a 
translation, please contact me to know if there allready is a translation 
progress for your language. Rather feel free to open the Qemulator.pot file in 
the install dir with any text editor and insert your translations there. There 
are some good editors to do this an easy way. One of the most used tools for 
that job is poedit http://www.poedit.net. If you send me this modified po file, 
your language may be implemented in one of the next versions of Qemulator and 
your credits will be addet to the translators list. 
+Qemulator now have multilanguage support. If you are interested in making a 
translation, please contact me to know if there already is a translation 
progress for your language. Rather feel free to open the Qemulator.pot file in 
the install dir with any text editor and insert your translations there. There 
are some good editors to do this an easy way. One of the most used tools for 
that job is poedit http://www.poedit.net. If you send me this modified po file, 
your language may be implemented in one of the next versions of Qemulator and 
your credits will be addet to the translators list. 
 
 Note: It's very important to leave all special chars and markup tags like <b> 
or \" as it is in the original english version!
 
only in patch2:
unchanged:
--- qemulator-0.5.orig/Qemulator.pot
+++ qemulator-0.5/Qemulator.pot
@@ -245,7 +245,7 @@
 
 #: 
/home/rainer/createweb/Projekte/python/Qemulator/usr/local/lib/qemulator/src/interface.c:767
 #: 
/home/rainer/createweb/Projekte/python/Qemulator/usr/local/lib/qemulator/src/interface.c:3595
-msgid "With \"auto hide stored settings\" enabled, config panel for the 
selected image/machine will be hidden automatically, if there allready is a 
stored configuration for this image/machine."
+msgid "With \"auto hide stored settings\" enabled, config panel for the 
selected image/machine will be hidden automatically, if there already is a 
stored configuration for this image/machine."
 msgstr ""
 
 #: 
/home/rainer/createweb/Projekte/python/Qemulator/usr/local/lib/qemulator/src/interface.c:775
@@ -2612,7 +2612,7 @@
 
 #: 
/home/rainer/createweb/Projekte/python/Qemulator/usr/local/lib/qemulator/qml_installwizzard.py:608
 #: 
/home/rainer/createweb/Projekte/python/Qemulator/usr/local/lib/qemulator/qml_machinesetup.py:1456
-msgid "A Machine with this name allready exists, please choose another one"
+msgid "A Machine with this name already exists, please choose another one"
 msgstr ""
 
 #: 
/home/rainer/createweb/Projekte/python/Qemulator/usr/local/lib/qemulator/qml_installwizzard.py:658
only in patch2:
unchanged:
--- qemulator-0.5.orig/usr/local/lib/qemulator/qemulator.glade
+++ qemulator-0.5/usr/local/lib/qemulator/qemulator.glade
@@ -937,7 +937,7 @@
                  <child>
                    <widget class="GtkCheckButton" 
id="checkbutton_autohide_settings">
                      <property name="visible">True</property>
-                     <property name="tooltip" translatable="yes">With 
&quot;auto hide stored settings&quot; enabled, config panel for the selected 
image/machine will be hidden automatically, if there allready is a stored 
configuration for this image/machine.</property>
+                     <property name="tooltip" translatable="yes">With 
&quot;auto hide stored settings&quot; enabled, config panel for the selected 
image/machine will be hidden automatically, if there already is a stored 
configuration for this image/machine.</property>
                      <property name="can_focus">True</property>
                      <property name="label" translatable="yes">auto 
hide</property>
                      <property name="use_underline">True</property>
@@ -7177,7 +7177,7 @@
                                      <child>
                                        <widget class="GtkCheckButton" 
id="checkbutton_autohide_settings">
                                          <property 
name="visible">True</property>
-                                         <property name="tooltip" 
translatable="yes">With &quot;auto hide stored settings&quot; enabled, config 
panel for the selected image/machine will be hidden automatically, if there 
allready is a stored configuration for this image/machine.</property>
+                                         <property name="tooltip" 
translatable="yes">With &quot;auto hide stored settings&quot; enabled, config 
panel for the selected image/machine will be hidden automatically, if there 
already is a stored configuration for this image/machine.</property>
                                          <property 
name="can_focus">True</property>
                                          <property name="label" 
translatable="yes">auto _hide stored settings</property>
                                          <property 
name="use_underline">True</property>
only in patch2:
unchanged:
--- qemulator-0.5.orig/usr/local/lib/qemulator/qml_machinesetup.py
+++ qemulator-0.5/usr/local/lib/qemulator/qml_machinesetup.py
@@ -1453,7 +1453,7 @@
             checkdouble = 
self.qemulator_instance.checkexist_bookmark(entry_name)
             #print 'doublecheck: ' + str(checkdouble)
             if checkdouble == True:
-                dialogtext = "<b>" + _("A Machine with this name allready 
exists, please choose another one") + "</b>"
+                dialogtext = "<b>" + _("A Machine with this name already 
exists, please choose another one") + "</b>"
                 delrequest = qml_tools.Dialog("error", dialogtext, "Name 
exists")
             else:  
                 #self.get_final_machine()             
only in patch2:
unchanged:
--- qemulator-0.5.orig/usr/local/lib/qemulator/qemulator.py
+++ qemulator-0.5/usr/local/lib/qemulator/qemulator.py
@@ -938,7 +938,7 @@
             
self.filechooserdialogUniversal.add_shortcut_folder(self.settings["imagespath"])
             #print "added imagespath to filechooserbuttonImagecdrom"
         except:
-            #print "imagespath allready on filechooserbuttonImagecdrom"
+            #print "imagespath already on filechooserbuttonImagecdrom"
             pass
         try:
             self.filechooserdialogUniversal.add_shortcut_folder("/dev/")
@@ -952,7 +952,7 @@
 #            
self.filechooserbuttonImagecdrom.add_shortcut_folder(self.settings["imagespath"])
 #            #print "added imagespath to filechooserbuttonImagecdrom"
 #        except:
-#            #print "imagespath allready on filechooserbuttonImagecdrom"
+#            #print "imagespath already on filechooserbuttonImagecdrom"
 #            pass
 #        try:
 #            self.filechooserbuttonImagecdrom.add_shortcut_folder("/dev/")
@@ -3827,7 +3827,7 @@
             #print 'check_keepname: ' + str(check_keepname)
             if check_keepname == False:
                 #print 'Updating config...'
-                #dialogtext = "<b>" + _("A Machine with this name allready 
exists, please choose another one") + "</b>"
+                #dialogtext = "<b>" + _("A Machine with this name already 
exists, please choose another one") + "</b>"
                 #delrequest = qml_tools.Dialog("error", dialogtext, "Name 
exists")
                 if haveconfig == True:
                     oldsettings = self.currimage_settings
@@ -5221,21 +5221,21 @@
         
     def check_firstrun(self):
         if os.path.exists(self.homedir):
-            #print "homedir '" + self.homedir + "' allready exists"
+            #print "homedir '" + self.homedir + "' already exists"
             pass
         else:
             print "homedir '" + self.homedir + "' will be created"
             os.mkdir(self.homedir)
             
         if os.path.exists(self.configdir):
-            #print "configdir '" + self.configdir + "' allready exists"
+            #print "configdir '" + self.configdir + "' already exists"
             pass
         else:
             print "configdir '" + self.configdir + "' will be created"
             os.mkdir(self.configdir)            
                     
         if os.path.exists(self.icondirs[1]):
-            #print "icondir '" + self.icondirs[1] + "' allready exists"
+            #print "icondir '" + self.icondirs[1] + "' already exists"
             pass
         else:
             print "icondir '" + self.icondirs[1] + "' will be created"
only in patch2:
unchanged:
--- qemulator-0.5.orig/usr/local/lib/qemulator/qml_installwizzard.py
+++ qemulator-0.5/usr/local/lib/qemulator/qml_installwizzard.py
@@ -605,7 +605,7 @@
             checkdouble = 
self.qemulator_instance.checkexist_bookmark(entry_name)
             #print 'doublecheck: ' + str(checkdouble)
             if checkdouble == True:
-                dialogtext = "<b>" + _("A Machine with this name allready 
exists, please choose another one") + "</b>"
+                dialogtext = "<b>" + _("A Machine with this name already 
exists, please choose another one") + "</b>"
                 delrequest = qml_tools.Dialog("error", dialogtext, "Name 
exists")
             else:  
                 #self.get_final_machine()             
only in patch2:
unchanged:
--- qemulator-0.5.orig/debian/patches/fix-snpashot-typo.patch
+++ qemulator-0.5/debian/patches/fix-snpashot-typo.patch
@@ -0,0 +1,27 @@
+Description: typo in qemulator: snpashot should be snapshot
+Author: Niall Jackson <niall.jack...@gmail.com>
+Bug-Ubuntu: http://launchpad.net/bugs/348172
+diff -Nur -x '*.orig' -x '*~' qemulator-0.5/Qemulator.pot 
qemulator-0.5.new/Qemulator.pot
+--- qemulator-0.5/Qemulator.pot        2007-06-16 01:32:13.000000000 +0100
++++ qemulator-0.5.new/Qemulator.pot    2009-09-05 15:29:46.384779081 +0100
+@@ -712,7 +712,7 @@
+ msgstr ""
+ 
+ #: 
/home/rainer/createweb/Projekte/python/Qemulator/usr/local/lib/qemulator/src/interface.c:1850
+-msgid "Snpashot mode"
++msgid "Snapshot mode"
+ msgstr ""
+ 
+ #: 
/home/rainer/createweb/Projekte/python/Qemulator/usr/local/lib/qemulator/src/interface.c:1855
+diff -Nur -x '*.orig' -x '*~' 
qemulator-0.5/usr/local/lib/qemulator/qemulator.glade 
qemulator-0.5.new/usr/local/lib/qemulator/qemulator.glade
+--- qemulator-0.5/usr/local/lib/qemulator/qemulator.glade      2007-06-16 
01:53:58.000000000 +0100
++++ qemulator-0.5.new/usr/local/lib/qemulator/qemulator.glade  2009-09-05 
15:30:11.416779798 +0100
+@@ -4413,7 +4413,7 @@
+                                             <property 
name="visible">True</property>
+                                             <property name="tooltip" 
translatable="yes">write to temporary files instead of disk image 
files</property>
+                                             <property 
name="can_focus">True</property>
+-                                            <property name="label" 
translatable="yes">Snpashot mode</property>
++                                            <property name="label" 
translatable="yes">Snapshot mode</property>
+                                             <property 
name="use_underline">True</property>
+                                             <property 
name="relief">GTK_RELIEF_NORMAL</property>
+                                             <property 
name="focus_on_click">True</property>

Reply via email to
--- qemulator-0.5.orig/setup.py
+++ qemulator-0.5/setup.py
@@ -832,7 +832,7 @@
                                                                                
                #else: 
                #inst_error = False 
                #print "user is allready root" 
                self.install_dirs(self.instdirs, mode)
                self.install_files(self.instfiles, mode)
                self.progress_feedback()
@@ -864,7 +864,7 @@
                                        except:
                                                pass
                                else:  
                                        #print "user is allready root"      
                                        command = "mkdir -v " + tdir
                                        child_stdin, child_stdout, child_stderr 
= os.popen3(command)
                                        child_stdin.close()     
@@ -877,7 +877,7 @@
                                        #print "created dir: " + tdir
                                self.progress_feedback()
                        else:
-                               print "Directory " + tdir + " allready exist"   
+                               print "Directory " + tdir + " already exist"    
                                
        def install_files(self, instfiles, mode):
                for sfile, tfile in instfiles:
@@ -890,7 +890,7 @@
                                child_stdin.flush()
                                child_stdin.close()
                        else:  
                                #print "user is allready root"      
                                command = "cp -dv " + sfile + " " + tfile
                                child_stdin, child_stdout, child_stderr = 
os.popen3(command)
                                child_stdin.close()     
@@ -942,7 +942,7 @@
                                                child_stdin.flush()
                                                child_stdin.close()     
                                        else:
-                                               #print "user is allready root"  
    
+                                               #print "user is already root"   
   
                                                command = "rm " + file
                                                child_stdin, child_stdout, 
child_stderr = os.popen3(command)
                                                child_stdin.close()
@@ -986,7 +986,7 @@
                                                                
child_stdin.flush()
                                                                
child_stdin.close()
                                                        else:  
-                                                               #print "user is 
allready root"      
+                                                               #print "user is 
already root"      
                                                                command = "rm 
-Rv " + dir
                                                                child_stdin, 
child_stdout, child_stderr = os.popen3(command)
                                                                
child_stdin.close()
@@ -1060,7 +1060,7 @@
                        child_stderr1.close()
                        child_stdout1.close()                                   
                        
                else:  
                        #print "user is allready root"      
 
                        child_stdin, child_stdout, child_stderr  = 
@@ -832,7 +832,7 @@
                #else: 
                #inst_error = False 
-               #print "user is allready root" 
+               #print "user is already root" 
                self.install_dirs(self.instdirs, mode)
                self.install_files(self.instfiles, mode)
@@ -864,7 +864,7 @@
                                                pass
                                else:  
-                                       #print "user is allready root"      
+                                       #print "user is already root"      
                                        command = "mkdir -v " + tdir
                                        child_stdin, child_stdout, child_stderr 
@@ -890,7 +890,7 @@
                                child_stdin.close()
                        else:  
-                               #print "user is allready root"      
+                               #print "user is already root"      
                                command = "cp -dv " + sfile + " " + tfile
                                child_stdin, child_stdout, child_stderr = 
@@ -1060,7 +1060,7 @@
                        
                else:  
-                       #print "user is allready root"      
+                       #print "user is already root"      
 
                        child_stdin, child_stdout, child_stderr  = 
os.popen3(insthist_command)
                        errors2 = child_stderr.readlines()
only in patch2:
unchanged: